==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WebhookConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class WebhookConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<A>{
  public WebhookConfigFluentImpl() {
  }
  public WebhookConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfig instance) {
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMaxAlerts(instance.getMaxAlerts()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withUrl(instance.getUrl()); 
    this.withUrlSecret(instance.getUrlSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder httpConfig;
  private java.lang.Integer maxAlerts;
  private java.lang.Boolean sendResolved;
  private java.lang.String url;
  private io.fabric8.kubernetes.api.model.SecretKeySelector urlSecret;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildHttpConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig getHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig buildHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public A withHttpConfig(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig httpConfig) {
    _visitables.get("httpConfig").remove(this.httpConfig);
    if (httpConfig!=null){ this.httpConfig= new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(httpConfig); _visitables.get("httpConfig").add(this.httpConfig);} return (A) this;
  }
  public java.lang.Boolean hasHttpConfig() {
    return this.httpConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> withNewHttpConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluentImpl.HttpConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> withNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluentImpl.HttpConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> editHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> editOrNewHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> editOrNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): item);
  }
  public java.lang.Integer getMaxAlerts() {
    return this.maxAlerts;
  }
  public A withMaxAlerts(java.lang.Integer maxAlerts) {
    this.maxAlerts=maxAlerts; return (A) this;
  }
  public java.lang.Boolean hasMaxAlerts() {
    return this.maxAlerts != null;
  }
  public java.lang.Boolean getSendResolved() {
    return this.sendResolved;
  }
  public A withSendResolved(java.lang.Boolean sendResolved) {
    this.sendResolved=sendResolved; return (A) this;
  }
  public java.lang.Boolean hasSendResolved() {
    return this.sendResolved != null;
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getUrlSecret() {
    return this.urlSecret;
  }
  public A withUrlSecret(io.fabric8.kubernetes.api.model.SecretKeySelector urlSecret) {
    this.urlSecret=urlSecret; return (A) this;
  }
  public java.lang.Boolean hasUrlSecret() {
    return this.urlSecret != null;
  }
  public A withNewUrlSecret(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withUrlSecret(new SecretKeySelector(key, name, optional));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WebhookConfigFluentImpl that = (WebhookConfigFluentImpl) o;
    if (httpConfig != null ? !httpConfig.equals(that.httpConfig) :that.httpConfig != null) return false;
    if (maxAlerts != null ? !maxAlerts.equals(that.maxAlerts) :that.maxAlerts != null) return false;
    if (sendResolved != null ? !sendResolved.equals(that.sendResolved) :that.sendResolved != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (urlSecret != null ? !urlSecret.equals(that.urlSecret) :that.urlSecret != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpConfig,  maxAlerts,  sendResolved,  url,  urlSecret,  additionalProperties,  super.hashCode());
  }
  public class HttpConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HttpConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this, item);
    }
    HttpConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder builder;
    public N and() {
      return (N) WebhookConfigFluentImpl.this.withHttpConfig(builder.build());
    }
    public N endHttpConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WebhookConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class WebhookConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<A>{
  public WebhookConfigFluentImpl() {
  }
  public WebhookConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfig instance) {
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMaxAlerts(instance.getMaxAlerts()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withUrl(instance.getUrl()); 
    this.withUrlSecret(instance.getUrlSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder httpConfig;
  private java.lang.Integer maxAlerts;
  private java.lang.Boolean sendResolved;
  private java.lang.String url;
  private io.fabric8.kubernetes.api.model.SecretKeySelector urlSecret;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildHttpConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig getHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig buildHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public A withHttpConfig(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig httpConfig) {
    _visitables.get("httpConfig").remove(this.httpConfig);
    if (httpConfig!=null){ this.httpConfig= new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(httpConfig); _visitables.get("httpConfig").add(this.httpConfig);} return (A) this;
  }
  public java.lang.Boolean hasHttpConfig() {
    return this.httpConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> withNewHttpConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluentImpl.HttpConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> withNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluentImpl.HttpConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> editHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> editOrNewHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<A> editOrNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): item);
  }
  public java.lang.Integer getMaxAlerts() {
    return this.maxAlerts;
  }
  public A withMaxAlerts(java.lang.Integer maxAlerts) {
    this.maxAlerts=maxAlerts; return (A) this;
  }
  public java.lang.Boolean hasMaxAlerts() {
    return this.maxAlerts != null;
  }
  public java.lang.Boolean getSendResolved() {
    return this.sendResolved;
  }
  public A withSendResolved(java.lang.Boolean sendResolved) {
    this.sendResolved=sendResolved; return (A) this;
  }
  public java.lang.Boolean hasSendResolved() {
    return this.sendResolved != null;
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getUrlSecret() {
    return this.urlSecret;
  }
  public A withUrlSecret(io.fabric8.kubernetes.api.model.SecretKeySelector urlSecret) {
    this.urlSecret=urlSecret; return (A) this;
  }
  public java.lang.Boolean hasUrlSecret() {
    return this.urlSecret != null;
  }
  public A withNewUrlSecret(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withUrlSecret(new SecretKeySelector(key, name, optional));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WebhookConfigFluentImpl that = (WebhookConfigFluentImpl) o;
    if (httpConfig != null ? !httpConfig.equals(that.httpConfig) :that.httpConfig != null) return false;
    if (maxAlerts != null ? !maxAlerts.equals(that.maxAlerts) :that.maxAlerts != null) return false;
    if (sendResolved != null ? !sendResolved.equals(that.sendResolved) :that.sendResolved != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (urlSecret != null ? !urlSecret.equals(that.urlSecret) :that.urlSecret != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpConfig,  maxAlerts,  sendResolved,  url,  urlSecret,  additionalProperties,  super.hashCode());
  }
  public class HttpConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent.HttpConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HttpConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this, item);
    }
    HttpConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder builder;
    public N and() {
      return (N) WebhookConfigFluentImpl.this.withHttpConfig(builder.build());
    }
    public N endHttpConfig() {
      return and();
    }
    
  }
  
}
